@@ -67,7 +67,9 @@ struct _GtkDataboxXYCGraphPrivate
    GType ytype;
 };
 
+/*
 static gpointer parent_class = NULL;
+*/
 
 void
 gtk_databox_xyc_graph_set_X_Y_length(GtkDataboxXYCGraph * xyc_graph, gfloat * X, gfloat * Y, guint len)
@@ -528,6 +530,7 @@ gtk_databox_xyc_graph_class_init (GtkDataboxXYCGraphClass *klass)
 static void
 gtk_databox_xyc_graph_init (GtkDataboxXYCGraph *xyc_graph)
 {
+	xyc_graph = xyc_graph;
 }
 
 static gint
