@@ -24,7 +24,7 @@
 # define TUTOR_BLACK "#000000"
 # define TUTOR_GRAY "#dddddd"
 # define TUTOR_GRAY_LITE "#eeece8"
-# define TUTOR_CREAM "#f0f2ca" /* "#faf8f8" before */
+# define TUTOR_CREAM "#f8f4f2" /* "#f0f2ca" <== "#faf8f8" before */
 # define TUTOR_WHITE "#fffefe"
 
 typedef enum
@@ -71,12 +71,16 @@ gint tutor_get_correcting (void);
 
 void tutor_init_timers (void);
 
+void tutor_init_goals (void);
+
 gdouble tutor_goal_accuracy (void);
 
 gdouble tutor_goal_speed (void);
 
 gdouble tutor_goal_fluidity (void);
 
+gdouble tutor_goal_level (guint n);
+
 /*
  * Auxiliar functions
  */
